aboutsummaryrefslogtreecommitdiffstats
path: root/Alc/effects/null.c
diff options
context:
space:
mode:
authorChris Robinson <[email protected]>2018-02-28 19:37:12 -0800
committerChris Robinson <[email protected]>2018-02-28 19:37:12 -0800
commita211c2f5e4d14678a77ab11d5d1879b2f442fe4c (patch)
treeab680f0bc375341c8e295fb1e60e66a8417f9b15 /Alc/effects/null.c
parentd25398d2c7efb02a9b8e630b15be3a7ab2578aa8 (diff)
Avoid AL prefix on internal effect state factory types
Also avoid using the generic V/V0 macros for them
Diffstat (limited to 'Alc/effects/null.c')
-rw-r--r--Alc/effects/null.c18
1 files changed, 9 insertions, 9 deletions
diff --git a/Alc/effects/null.c b/Alc/effects/null.c
index f9583011..e57359e3 100644
--- a/Alc/effects/null.c
+++ b/Alc/effects/null.c
@@ -85,12 +85,12 @@ static void ALnullState_Delete(void *ptr)
}
-typedef struct ALnullStateFactory {
- DERIVE_FROM_TYPE(ALeffectStateFactory);
-} ALnullStateFactory;
+typedef struct NullStateFactory {
+ DERIVE_FROM_TYPE(EffectStateFactory);
+} NullStateFactory;
/* Creates ALeffectState objects of the appropriate type. */
-ALeffectState *ALnullStateFactory_create(ALnullStateFactory *UNUSED(factory))
+ALeffectState *NullStateFactory_create(NullStateFactory *UNUSED(factory))
{
ALnullState *state;
@@ -100,13 +100,13 @@ ALeffectState *ALnullStateFactory_create(ALnullStateFactory *UNUSED(factory))
return STATIC_CAST(ALeffectState, state);
}
-/* Define the ALeffectStateFactory vtable for this type. */
-DEFINE_ALEFFECTSTATEFACTORY_VTABLE(ALnullStateFactory);
+/* Define the EffectStateFactory vtable for this type. */
+DEFINE_EFFECTSTATEFACTORY_VTABLE(NullStateFactory);
-ALeffectStateFactory *ALnullStateFactory_getFactory(void)
+EffectStateFactory *NullStateFactory_getFactory(void)
{
- static ALnullStateFactory NullFactory = { { GET_VTABLE2(ALnullStateFactory, ALeffectStateFactory) } };
- return STATIC_CAST(ALeffectStateFactory, &NullFactory);
+ static NullStateFactory NullFactory = { { GET_VTABLE2(NullStateFactory, EffectStateFactory) } };
+ return STATIC_CAST(EffectStateFactory, &NullFactory);
}